"""Assets Package

This package provides classes for different types of assets, including MediaAsset, TextAsset, and MultiAsset.
"""

from .media_asset import MediaAsset
from .text_asset import TextAsset
from .multi_asset import MultiAsset
